@@ -1,3 +1,3 @@
 import { a } from "x";
 import b from "y";
-a, b();
+const arr = (a, b());
